@@ -104,12 +104,6 @@ module Fcf
   , type (&&)
   , Not
 
-    -- *** Multi-way if
-
-  , Guarded
-  , Guard((:=))
-  , Otherwise
-
     -- ** Case splitting
 
   , Case
@@ -152,5 +146,6 @@ import Fcf.Data.Bool
 import Fcf.Data.Common
 import Fcf.Data.List
 import Fcf.Data.Nat
-import Fcf.Classes
+import Fcf.Class.Functor
+import Fcf.Class.Bifunctor
 import Fcf.Utils
